To facilitate comparisons between 3D and 2D approaches, the compare_2D_3D()
function is provided in the package. This function enables users to conduct all steps of
the analysis (data generation, setting and solving the optimization problem
and producing outputs), by executing both 2D and 3D approaches, with similar settings,
that facilitate comparisons. The function generates corresponding maps and graphs for
both approaches.
The split_rast function is used to convert 2D distributions of
biodiversity features (rasters) into a 3D format.
Here the biodiv_df can have the following
column names (independently of their order and any other names are ignored):
"species_name": Mandatory column with the feature names, which must
be the same with biodiv_raster.
"pelagic": Mandatory column about the features' behaviour.
TRUE means that this feature is pelagic and FALSE means that this feature is
benthic.
"min_z": Optional column about the minimum vertical range of
features. NA values are translated as unlimited upward feature movement.
"max_z": Optional column about the maximum vertical range of
features. NA values are translated as unlimited downward feature movement.
"group": Optional column with the group weights names.
Except from biodiv_df, an additional data.frame object can also be used for
defining group weights, named priority_weights. If used, this data.frame
object must have two columns:
In case that no feature weights are desired, then priority_weights can be kept
to NULL.
breaks must be in correspondence to depth_raster file.
For example, if depth_raster has range \([10, -3000]\), then a breaks vector of
c(0,-40,-200,-2000,-Inf) will create depth levels
\([0,-40],\\(-40,-200], (-200, -2000], (-2000, -\infty)\)
and set to NA cells with values greater than \(0\).
If val_depth_range = TRUE (default), then no correction is done and the depth range
of the biodiversity features is derived from the corresponding feature distribution
raster and so "min_z" and "max_z" are ignored.
If val_depth_range = FALSE, then the function uses the minimum and maximum depth
information provided in the biodiv_df, so as to remove feature occurrences outside their
expected range.
budget_percents: Budget reflects the desired level of protection to be modeled.
It ranges from 0 to 1, with 0 indicating no resources available for protection,
while 1 signifies resources sufficient to protect the entire study area. Typically,
setting a budget of 0.3 corresponds to the 30% conservation target (i.e. 30% of the
total area set aside for conservation).
Users also have the flexibility to define multiple budget levels using a vector,
allowing for the exploration of various protection scenarios. For instance, a vector like
c(0.1, 0.3, 0.5) represents three scenarios where 10%, 30%, and 50% of the
study area are designated for protection.
budget_weights: The Compare_2D_3D function allows users to specify how the
budget is distributed among depth levels. Three allocation methods are available:
Equal Distribution: Allocates an equal share of the budget to each depth level
(budget_weights = "equal").
Proportional to Area: Allocates budget based on the spatial extent of each depth
level
(budget_weights = "area").
Proportional to Species Richness: Prioritizes budget allocation to depth levels with
higher species diversity (number of species). (budget_weights = "richness")
Otherwise, it can be a numeric vector with length equal to the number of depth levels,
where each number indicates the budget share per depth level.
The solver used for solving the prioritization problems is the best available on the
computer, following the solver hierarchy of prioritizr.