terra_jaccard: Jaccard similarity coefficient among two SpatRaster objects
Description
Jaccard coefficient among two SpatRaster objects
Usage
terra_jaccard(x, y)
Value
A numeric value \([0,1]\).
Arguments
x
SpatRaster object with binary values.
y
SpatRaster object with binary values.
Details
Jaccard similarity coefficient evaluates the percentage number equal to the intersection
between two sets, divided by the size of the union of these sets.